library(testthat)
library(windfarmGA)
library(rgdal)
library(rgeos)

test_check("windfarmGA")
